@@ -32,6 +32,18 @@ class UnmanagedEntityError(Exception):
                 added to world'''.format(self.entity)
 
 
+class UnmanagedSystemError(Exception):
+    def __init__(self, system):
+        self.system = system
+
+    def __repr__(self):
+        return self.__str__()
+
+    def __str__(self):
+        return '''{0} you were trying to use in world has not been
+                added to world'''.format(self.system)
+
+
 class NonUniqueTagError(Exception):
     def __init__(self, tag):
         self.tag = tag
@@ -42,3 +54,14 @@ class NonUniqueTagError(Exception):
     def __str__(self):
         return '''Tag {0} you were trying to use in world has already been
                 added to world'''.format(self.tag)
+
+
+class DeadEntityError(Exception):
+    def __init__(self):
+        pass
+
+    def __repr__(self):
+        return self.__str__()
+
+    def __str__(self):
+        return 'Dead entity cannot be used'
